require './spec/spec_helper'

describe Structura::Cfg.instance do

  before do
    stub_const "FakeCfgClass", Structura::Cfg.clone
  end

  it "can`'t use the Cfg without loading a configuration file'" do
    expect {FakeCfgClass.instance.read_value 'aaa', 'bbb'}.to raise_error LoadError
  end

  it "is_string: exceptions and working" do
    expect {FakeCfgClass.instance.is_string 123}.to raise_error ArgumentError
    expect {FakeCfgClass.instance.is_string '123'}.not_to raise_error
  end

  it "string_to_symbol: convert string to symbol" do
    expect(FakeCfgClass.instance.string_to_symbol("string")).to eq :string
  end

  it "Cfg will raise exception when using non string arguments" do
    FakeCfgClass.instance.load_file 'spec/config.yaml'
    expect {FakeCfgClass.instance.read_value(:section, :value)}.to raise_error ArgumentError
  end

  it "Cfg read expected values, return false for values that don't exist" do
    FakeCfgClass.instance.load_file 'spec/config.yaml'

    FakeCfgClass.instance.read_value('section_one', 'one').should eq 'one'
    FakeCfgClass.instance.read_value('section_one', 'two').should eq 'two'
    FakeCfgClass.instance.read_value('section_two', 'one').should eq 'one'

    FakeCfgClass.instance.read_value('section_one', 'fake_value').should be_false
    FakeCfgClass.instance.read_value('fake_section', 'one').should be_false
  end

end
